summaryrefslogtreecommitdiffstats
path: root/Include/intobject.h
diff options
context:
space:
mode:
authorMark Hammond <mhammond@skippinet.com.au>2002-08-12 07:21:58 (GMT)
committerMark Hammond <mhammond@skippinet.com.au>2002-08-12 07:21:58 (GMT)
commit91a681debf9ffec155d0aff8a0bb5f965f592e16 (patch)
tree09f28782e3b0a24e64deddeafc9df24ac93855ca /Include/intobject.h
parent44121a6bc9828c993932b87e442440dc4f260f3c (diff)
downloadcpython-91a681debf9ffec155d0aff8a0bb5f965f592e16.zip
cpython-91a681debf9ffec155d0aff8a0bb5f965f592e16.tar.gz
cpython-91a681debf9ffec155d0aff8a0bb5f965f592e16.tar.bz2
Excise DL_EXPORT from Include.
Thanks to Skip Montanaro and Kalle Svensson for the patches.
Diffstat (limited to 'Include/intobject.h')
-rw-r--r--Include/intobject.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/Include/intobject.h b/Include/intobject.h
index f48894c..ab936b2 100644
--- a/Include/intobject.h
+++ b/Include/intobject.h
@@ -25,30 +25,30 @@ typedef struct {
long ob_ival;
} PyIntObject;
-extern DL_IMPORT(PyTypeObject) PyInt_Type;
+PyAPI_DATA(PyTypeObject) PyInt_Type;
#define PyInt_Check(op) PyObject_TypeCheck(op, &PyInt_Type)
#define PyInt_CheckExact(op) ((op)->ob_type == &PyInt_Type)
-extern DL_IMPORT(PyObject *) PyInt_FromString(char*, char**, int);
+PyAPI_FUNC(PyObject *) PyInt_FromString(char*, char**, int);
#ifdef Py_USING_UNICODE
-extern DL_IMPORT(PyObject *) PyInt_FromUnicode(Py_UNICODE*, int, int);
+PyAPI_FUNC(PyObject *) PyInt_FromUnicode(Py_UNICODE*, int, int);
#endif
-extern DL_IMPORT(PyObject *) PyInt_FromLong(long);
-extern DL_IMPORT(long) PyInt_AsLong(PyObject *);
-extern DL_IMPORT(long) PyInt_GetMax(void);
+PyAPI_FUNC(PyObject *) PyInt_FromLong(long);
+PyAPI_FUNC(long) PyInt_AsLong(PyObject *);
+PyAPI_FUNC(long) PyInt_GetMax(void);
/* Macro, trading safety for speed */
#define PyInt_AS_LONG(op) (((PyIntObject *)(op))->ob_ival)
/* These aren't really part of the Int object, but they're handy; the protos
* are necessary for systems that need the magic of DL_IMPORT and that want
* to have stropmodule as a dynamically loaded module instead of building it
* into the main Python shared library/DLL. Guido thinks I'm weird for
* building it this way. :-) [cjh]
*/
-extern DL_IMPORT(unsigned long) PyOS_strtoul(char *, char **, int);
-extern DL_IMPORT(long) PyOS_strtol(char *, char **, int);
+PyAPI_FUNC(unsigned long) PyOS_strtoul(char *, char **, int);
+PyAPI_FUNC(long) PyOS_strtol(char *, char **, int);
#ifdef __cplusplus
}
@@ -25,30 +25,30 @@ typedef struct {
#define PyInt_AS_LONG(op) (((PyIntObject *)(op))->ob_ival)
/* These aren't really part of the Int object, but they're handy; the protos
- * are necessary for systems that need the magic of DL_IMPORT and that want
+ * are necessary for systems that need the magic of PyAPI_FUNC and that want
* to have stropmodule as a dynamically loaded module instead of building it
* into the main Python shared library/DLL. Guido thinks I'm weird for